# AETIAN

**AETernus Intelligens — Adiutor et Nuntius**
*(Eternal Intelligence — Helper and Messenger)*

AI agent framework. Coming soon.

- Website: [aetian.ai](https://aetian.ai)
- GitHub: [github.com/aetian](https://github.com/aetian)
